# NeuGym

NeuGym is a Python package for reinforcement learning environment of animal behavior modeling, 
which is still under development.

* **Documentation:** https://neugym.readthedocs.io/en/latest/
* **Mailing list:** https://groups.google.com/g/neugym
* **Source code:** https://github.com/HaoZhu10015/neugym
* **Bug reports:** https://github.com/HaoZhu10015/neugym/issues
* **Tutorial (TODO):** https://neugym.readthedocs.io/en/latest/tutorial.html

## Install

Install the current release of NeuGym with ``pip``: 

    $ pip install neugym

For more installing options please refer to [Install].

## Citation

If you find this code useful for your research, please cite:

    @misc{HaoZhu10015_2022_NeuGym,
      author = {Hao Zhu},
      title = {NeuGym},
      year = {2022},
      publisher = {GitHub},
      journal = {GitHub repository},
      howpublished = {\url{https://github.com/HaoZhu10015/neugym}},
    }


## Code of conduct

Anyone who interacts with this software in any space, 
including but not limited to this GitHub repository, 
must follow our [code of conduct](code_of_conduct.md).